@@ -22,29 +22,28 @@ class Config(object):
     MANAGER_PORT = 16501
     MANAGER_HTTP_PORT = 16500
 
-    def __init__(self, path=None):
+    def __init__(self, module=None):
         """Initialize Config from a module.
         Configuration options must be prefixed with "KUYRUK_".
         They are stripped when the Config object is initialized.
 
         """
-        if path:
-            self.path = path
-            self._load_module()
+        if module is None:
+            module = imp.new_module('kuyruk_config')
 
-    def reload(self):
-        assert self.path
-        logger.warning("Reloading config from %s", self.path)
-        self._clear()
+        self.module = module
         self._load_module()
 
+    @classmethod
+    def from_path(cls, path=None):
+        if path:
+            module = imp.load_source('kuyruk_config', path)
+            return cls(module)
+        else:
+            return cls()
+
     def _load_module(self):
-        module = imp.load_source('kuyruk_user_config', self.path)
-        for k, v in module.__dict__.iteritems():
+        for k, v in self.module.__dict__.iteritems():
             if k.startswith('KUYRUK_'):
                 setattr(self, k[7:], v)
-        logger.info("Config is loaded from %s", self.path)
-
-    def _clear(self):
-        for k, v in self.__dict__.items():
-            delattr(self, k)
+        logger.info("Config is loaded from %r", self.module)
